# Ket Bitwise Simulator

Ket Bitwise Simulator (KBW) is a noise-free quantum computer simulator that allows anyone to test quantum applications on classical computers

KBW features two simulation methods:

* **Dense** simulation based on state vector simulation, and
* **Sparse** simulation based on the Bitwise representation.

This project is part of the Ket Quantum Programming platform, see the documentation for
more information <https://quantumket.org>.

## Ket Quantum Programming platform  

![Ket Quantum Programming platform architecture](https://gitlab.com/quantum-ket/ket-everywhere/-/raw/main/architecture.png)

## Examples

For examples of KBW being used in Python (Ket), Rust, C, and C++, check out the [Ket Everywhere repository](https://gitlab.com/quantum-ket/ket-everywhere).

## License

Libket is released under the Apache-2.0 License. See [LICENSE](LICENSE) for more information.
